/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_DOCUMENT_FORMATS_H_
#define _GB2_DOCUMENT_FORMATS_H_

#include "core_api.h"

namespace GB2 {

class GB2_COREAPI_EXPORT BaseDocumentFormats {
public:
	static const DocumentFormatId PLAIN_TEXT;
	static const DocumentFormatId PLAIN_FASTA;
	static const DocumentFormatId PLAIN_GENBANK;
    static const DocumentFormatId PLAIN_EMBL;
	static const DocumentFormatId ABIF;
    static const DocumentFormatId SCF;
    static const DocumentFormatId RAW_DNA_SEQUENCE;
    static const DocumentFormatId CLUSTAL_ALN;
    static const DocumentFormatId STOCKHOLM;
    static const DocumentFormatId NEWICK;
	static const DocumentFormatId PLAIN_PDB; 
	static const DocumentFormatId INDEX;
    static const DocumentFormatId FASTQ;
    static const DocumentFormatId PLAIN_ASN;
    static const DocumentFormatId MSF;
    static const DocumentFormatId GFF;
    static const DocumentFormatId SRF;
	static const DocumentFormatId SAM;
};


}//namespace

#endif
